@@ -46,7 +46,7 @@ def main():
             if produto_skyhub:
                 print(produto_skyhub)
                 if produto_skyhub.price != row[1] or produto_skyhub.qty != row[2]:
-                    produto_skyhub.atualiza_produto(produto_estoque)
+                    skyhub_controller.atualiza_produto(produto_estoque)
                     pass
 
             if produto_bling:
